<a id="base_window.*"></a>

## \*

<a id="base_window.Path"></a>

## Path

<a id="base_window.BaseMainWindow"></a>

## BaseMainWindow Objects

```python
class BaseMainWindow(QMainWindow)
```

<a id="base_window.BaseMainWindow.__init__"></a>

#### \_\_init\_\_

```python
def __init__(*args, **kwargs)
```

<a id="base_window.BaseMainWindow.closeEvent"></a>

#### closeEvent

```python
def closeEvent(event)
```

<a id="base_window.BaseMainWindow.save_settings"></a>

#### save\_settings

```python
def save_settings()
```

<a id="base_window.BaseMainWindow.load_settings"></a>

#### load\_settings

```python
def load_settings()
```

